@@ -8,7 +8,6 @@ from threading import Timer
 from flask import request, jsonify
 
 
-KABLE_ENVIRONMENT_HEADER_KEY = 'KABLE-ENVIRONMENT'
 KABLE_CLIENT_ID_HEADER_KEY = 'KABLE-CLIENT-ID'
 KABLE_CLIENT_SECRET_HEADER_KEY = 'KABLE-CLIENT-SECRET'
 X_CLIENT_ID_HEADER_KEY = 'X-CLIENT-ID'
@@ -20,31 +19,26 @@ class Kable:
 
     def __init__(self, config):
 
-        print("Initializing Kable")
+        print("[KABLE] Initializing Kable")
 
         if config is None:
             raise RuntimeError(
                 "[KABLE] Failed to initialize Kable: config not provided")
 
-        if "environment" not in config:
+        if "kable_client_id" not in config:
             raise RuntimeError(
-                '[KABLE] Failed to initialize Kable: environment not provided')
+                '[KABLE] Failed to initialize Kable: kable_client_id not provided')
 
-        if "client_id" not in config:
+        if "kable_client_secret" not in config:
             raise RuntimeError(
-                '[KABLE] Failed to initialize Kable: client_id not provided')
-
-        if "client_secret" not in config:
-            raise RuntimeError(
-                '[KABLE] Failed to initialize Kable: client_secret not provided')
+                '[KABLE] Failed to initialize Kable: kable_client_secret not provided')
 
         if "base_url" not in config:
             raise RuntimeError(
                 '[KABLE] Failed to initialize Kable: base_url not provided')
 
-        self.environment = config["environment"]
-        self.kableClientId = config["client_id"]
-        self.kableClientSecret = config["client_secret"]
+        self.kableClientId = config["kable_client_id"]
+        self.kableClientSecret = config["kable_client_secret"]
         self.baseUrl = config["base_url"]
 
         if "debug" in config:
@@ -56,10 +50,10 @@ class Kable:
 
         if "max_queue_size" in config:
             self.maxQueueSize = config["max_queue_size"]
-            if self.maxQueueSize > 100:
-                self.maxQueueSize = 100
+            if self.maxQueueSize > 500:
+                self.maxQueueSize = 500
         else:
-            self.maxQueueSize = 10 # flush after 10 requests queued
+            self.maxQueueSize = 10  # flush after 10 requests queued
 
         if "disable_cache" in config:
             disableCache = config["disable_cache"]
@@ -68,7 +62,6 @@ class Kable:
         print("[KABLE] Starting Kable with max_queue_size " +
               str(self.maxQueueSize))
 
-
         if "record_authentication" in config:
             self.recordAuthentication = config["record_authentication"]
             if self.recordAuthentication is False:
@@ -86,7 +79,6 @@ class Kable:
 
         url = f"{self.baseUrl}/api/authenticate"
         headers = {
-            KABLE_ENVIRONMENT_HEADER_KEY: self.environment,
             KABLE_CLIENT_ID_HEADER_KEY: self.kableClientId,
             X_CLIENT_ID_HEADER_KEY: self.kableClientId,
             X_API_KEY_HEADER_KEY: self.kableClientSecret,
@@ -127,13 +119,7 @@ class Kable:
             clientId = data['clientId']
             del data['clientId']
 
-        customerId = None
-        if 'customerId' in data:
-            customerId = data['customerId']
-            del data['customerId']
-
-        self.enqueueMessage(clientId=clientId,
-                            customerId=customerId, data=data)
+        self.enqueueEvent(clientId=clientId, data=data)
 
     def authenticate(self, api):
         @wraps(api)
@@ -146,7 +132,7 @@ class Kable:
             clientId = headers[X_CLIENT_ID_HEADER_KEY] if X_CLIENT_ID_HEADER_KEY in headers else None
             secretKey = headers[X_API_KEY_HEADER_KEY] if X_API_KEY_HEADER_KEY in headers else None
 
-            if self.environment is None or self.kableClientId is None:
+            if self.baseUrl is None or self.kableClientId is None:
                 return jsonify({"message": "Unauthorized. Failed to initialize Kable: Configuration invalid"}), 500
 
             if clientId is None or secretKey is None:
@@ -157,7 +143,7 @@ class Kable:
                     if self.debug:
                         print("[KABLE] Valid Cache Hit")
                     if self.recordAuthentication:
-                        self.enqueueMessage(clientId, None, {})
+                        self.enqueueEvent(clientId, {})
                     return api(*args, **kwargs)
 
             if secretKey in self.invalidCache:
@@ -167,11 +153,10 @@ class Kable:
                     return jsonify({"message": "Unauthorized"}), 401
 
             if self.debug:
-                print("Authenticating at server")
+                print("[KABLE] Authenticating at server")
 
             url = f"{self.baseUrl}/api/authenticate"
             headers = {
-                KABLE_ENVIRONMENT_HEADER_KEY: self.environment,
                 KABLE_CLIENT_ID_HEADER_KEY: self.kableClientId,
                 X_CLIENT_ID_HEADER_KEY: clientId,
                 X_API_KEY_HEADER_KEY: secretKey,
@@ -182,7 +167,7 @@ class Kable:
                 if status == 200:
                     self.validCache.__setitem__(secretKey, clientId)
                     if self.recordAuthentication:
-                        self.enqueueMessage(clientId, None, {})
+                        self.enqueueEvent(clientId, {})
                     return api(*args, **kwargs)
                 else:
                     if status == 401:
@@ -199,19 +184,17 @@ class Kable:
 
         return decoratedApi
 
-    def enqueueMessage(self, clientId, customerId, data):
+    def enqueueEvent(self, clientId, data):
         event = {}
-        event['environment'] = self.environment
         event['kableClientId'] = self.kableClientId
         event['clientId'] = clientId
-        event['customerId'] = customerId
         event['timestamp'] = datetime.utcnow().isoformat()
 
         event['data'] = data
 
         library = {}
         library['name'] = 'kable-python-flask'
-        library['version'] = '2.4.1'
+        library['version'] = '2.5.1'
 
         event['library'] = library
 
@@ -230,16 +213,13 @@ class Kable:
             if self.debug:
                 print(f'[KABLE] Sending {count} batched events to server')
 
-            url = f"{self.baseUrl}/api/events"
+            url = f"{self.baseUrl}/api/events/create"
             headers = {
-                KABLE_ENVIRONMENT_HEADER_KEY: self.environment,
                 KABLE_CLIENT_ID_HEADER_KEY: self.kableClientId,
-                X_CLIENT_ID_HEADER_KEY: self.kableClientId,
-                X_API_KEY_HEADER_KEY: self.kableClientSecret
+                KABLE_CLIENT_SECRET_HEADER_KEY: self.kableClientSecret,
             }
             try:
-                response = requests.post(
-                    url=url, headers=headers, json=events)
+                response = requests.post(url=url, headers=headers, json=events)
                 status = response.status_code
                 if status == 200:
                     print(
@@ -252,7 +232,7 @@ class Kable:
 
             except Exception as e:
                 print(e)
-                print(f'Failed to send {count} events to Kable server')
+                print(f'[KABLE] Failed to send {count} events to Kable server')
                 for event in events:
                     print(f'[KABLE] Kable Event (Error): {event}')
 
@@ -263,10 +243,11 @@ class Kable:
     def startFlushQueueTimer(self):
         if self.debug:
             print('[KABLE] Starting time-based queue poller')
-        self.queueFlushTimer = Kable.RepeatedTimer(self.queueFlushInterval, self.flushQueue)
+        self.queueFlushTimer = Kable.RepeatedTimer(
+            self.queueFlushInterval, self.flushQueue)
         self.queueFlushTimer.start()
 
-    def exitGracefully(self, *args): #args is necessary for signal handler
+    def exitGracefully(self, *args):  # args is necessary for signal handler
         if self.debug:
             print(f'[KABLE] Kable shutting down')
         self.flushQueue()
